==> ns-1.0a13.tar.gz: ns-1.0a13/object.h <==
/*
 * Copyright (c) 1993 Regents of the University of California.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *	This product includes software developed by the Computer Systems
 *	Engineering Group at Lawrence Berkeley Laboratory.
 * 4. Neither the name of the University nor of the Laboratory may be used
 *    to endorse or promote products derived from this software without
 *    specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 * @(#) $Header: object.h,v 1.9 95/11/04 14:28:48 mccanne Exp $ (LBL)
 */

#ifndef ns_object_h
#define ns_object_h

#include "Tcl.h"

class Var;
class Trace;

class NsObject : public TclObject {
 public:
	NsObject();
	virtual ~NsObject();
	virtual int command(int argc, const char*const* argv);
	void link_bool(const char* a, const char* fld, int* val, int readOnly);
	void link_int(const char* a, const char* fld, int* val, int readOnly);
	void link_real(const char* a, const char* fld,
		       double* val, int readOnly);
	void link_bw(const char* a, const char* fld,
		     double* val, int readOnly);
	void link_time(const char* a, const char* fld,
		     double* val, int readOnly);
 protected:
	void insert(Var* p);
	Var* varlookup(const char* var) const;
	int get(const char* var);
	int set(const char* val, const char* val);
	void linkvar(const char* fld, char* val, int flag, int readOnly);
	Var* var_;
	Trace* trace_;
};

#endif

==> ns-1.1.tar.gz: ns-1.1/object.h <==
/*
 * Copyright (c) 1993 Regents of the University of California.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *	This product includes software developed by the Computer Systems
 *	Engineering Group at Lawrence Berkeley Laboratory.
 * 4. Neither the name of the University nor of the Laboratory may be used
 *    to endorse or promote products derived from this software without
 *    specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 * @(#) $Header: /n/olympus/opt/users/CVS/ns-1.1-master/object.h,v 1.2 1997/09/08 20:51:06 wuchang Exp $ (LBL)
 */

#ifndef ns_object_h
#define ns_object_h

#include "Tcl.h"

class Var;
class Trace;

class NsObject : public TclObject {
 public:
	NsObject();
	virtual ~NsObject();
	virtual int command(int argc, const char*const* argv);
	void link_bool(const char* a, const char* fld, int* val, int readOnly);
	void link_int(const char* a, const char* fld, int* val, int readOnly);
	void link_real(const char* a, const char* fld,
		       double* val, int readOnly);
	void link_bw(const char* a, const char* fld,
		     double* val, int readOnly);
	void link_time(const char* a, const char* fld,
		     double* val, int readOnly);
 protected:
	void insert(Var* p);
	Var* varlookup(const char* var) const;
	int get(const char* var);
	int set(const char* var, const char* val);
	void linkvar(const char* fld, char* val, int flag, int readOnly);
	Var* var_;
	Trace* trace_;
};

#endif
